FlutterMtpPickerPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- FlutterMtpPickerPlatform
- Implementers
Constructors
- FlutterMtpPickerPlatform()
- Constructs a FlutterMtpPickerPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyFilesToLocal(
{required String deviceId, required Map< String, String> files}) → Future<List< String> > -
copyFileToLocal(
{required String deviceId, required String fileId, required String destinationPath}) → Future< String> -
getDevices(
) → Future< List< MtpDevice> > -
listChildren(
{required String deviceId, required String objectId}) → Future< List< MtpObject> > -
listMediaFiles(
{required String deviceId, required String folderId, required List< String> extensions}) → Future<List< MtpFile> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FlutterMtpPickerPlatform
-
The default instance of FlutterMtpPickerPlatform to use.
getter/setter pair