MtpFile class

Constructors

MtpFile({required String id, required String name, required int size})
const
MtpFile.fromMap(Map<Object?, Object?> map)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override