MtpFolderSelection class

Constructors

MtpFolderSelection({required MtpDevice device, required MtpObject folder})
const

Properties

device MtpDevice
final
folder MtpObject
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override