MethodChannelFlutterMtpPicker class
An implementation of FlutterMtpPickerPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- FlutterMtpPickerPlatform
- MethodChannelFlutterMtpPicker
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyFilesToLocal(
{required String deviceId, required Map< String, String> files}) → Future<List< String> > -
override
-
copyFileToLocal(
{required String deviceId, required String fileId, required String destinationPath}) → Future< String> -
override
-
getDevices(
) → Future< List< MtpDevice> > -
override
-
listChildren(
{required String deviceId, required String objectId}) → Future< List< MtpObject> > -
override
-
listMediaFiles(
{required String deviceId, required String folderId, required List< String> extensions}) → Future<List< MtpFile> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited