MtpPicker class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
copyFilesToLocal(
{required String deviceId, required Map< String, String> files}) → Future<List< String> > -
copyFileToLocal(
{required String deviceId, required String fileId, required String destinationPath}) → Future< String> -
getDevices(
) → Future< List< MtpDevice> > -
listChildren(
{required String deviceId, required String objectId}) → Future< List< MtpObject> > -
listMediaFiles(
{required String deviceId, required String folderId, required List< String> extensions}) → Future<List< MtpFile> > -
pickFolder(
BuildContext context) → Future< MtpFolderSelection?> -
pickFolders(
BuildContext context) → Future< List< MtpFolderSelection> ?>